Keen | Footer Callback Examples
Description: Footer callback datatables examples

# Customer Relationship Management

New Order

### Footer Callback Examples

Reports
Through the use of the header and footer callback manipulation functions provided by DataTables (headerCallback and footerCallback), it is possible to perform some powerful and useful data manipulation functions, such as summarising data in the table. See official documentation here.

### Footer Callback

Order ID | Ship Country | Ship City | Ship Address | Company Agent | Company Name | Total Payment
--- | --- | --- | --- | --- | --- | ---
61715-075 | CN | Tieba | 746 Pine View Junction | Nixie Sailor | Gleichner, Ziemann and Gutkowski | $246154.65
63629-4697 | ID | Cihaur | 01652 Fulton Trail | Emelita Giraldez | Rosenbaum-Reichel | $795849.41
68084-123 | AR | Puerto Iguazú | 2 Pine View Park | Ula Luckin | Kulas, Cassin and Batz | $830764.07
67457-428 | ID | Talok | 3050 Buell Terrace | Evangeline Cure | Pfannerstill-Treutel | $777892.92
31722-529 | AT | Sankt Andrä-Höch | 3038 Trailsway Junction | Tierney St. Louis | Dicki-Kling | $516467.41
64117-168 | CN | Rongkou | 023 South Way | Gerhard Reinhard | Gleason, Kub and Marquardt | $410062.16
43857-0331 | CN | Baiguo | 56482 Fairfield Terrace | Englebert Shelley | Jenkins Inc | $210902.65
64980-196 | HR | Vinica | 0 Elka Street | Hazlett Kite | Streich LLC | $1162836.25
0404-0360 | CO | San Carlos | 38099 Ilene Hill | Freida Morby | Haley, Schamberger and Durgan | $124768.15
52125-267 | TH | Maha Sarakham | 8696 Barby Pass | Obed Helian | Labadie, Predovic and Hammes | $531999.26
54092-515 | BR | Canguaretama | 32461 Ridgeway Alley | Sibyl Amy | Treutel-Ratke | $942781.29
0185-0130 | CN | Jiamachi | 23 Walton Pass | Norri Foldes | Strosin, Nitzsche and Wisozk | $1143125.96
21130-678 | CN | Qiaole | 328 Glendale Hill | Myrna Orhtmann | Miller-Schiller | $159355.37
40076-953 | PT | Burgau | 52550 Crownhardt Court | Sioux Kneath | Rice, Cole and Spinka | $381148.49
36987-3005 | PT | Bacelo | 548 Morrow Terrace | Christa Jacmar | Brakus-Hansen | $839071.50
67510-0062 | ZA | Pongola | 02534 Hauk Trail | Shandee Goracci | Bergnaum, Thiel and Schuppe | $924771.59
36987-2542 | RU | Novokizhinginsk | 19427 Sloan Road | Jerrome Colvie | Kreiger, Glover and Connelly | $708846.15
11673-479 | BR | Conceição das Alagoas | 191 Stone Corner Road | Michaelina Plenderleith | Legros-Gleichner | $1096683.96
47781-264 | UA | Yasinya | 1481 Sauthoff Place | Lombard Luthwood | Haag LLC | $810285.52
42291-712 | ID | Kembang | 9029 Blackbird Point | Leonora Chevin | Mann LLC | $868444.96
Order ID | Ship Country | Ship City | Ship Address | Company Agent | Company Name | Total Payment

### Quick Actions

Orders
Uploades
Products
Customers
Blog Posts
Settings
02:30 PM
KeenThemes created new layout whith tens of new options for Keen Admin panel
HTML,CSS,VueJS
01:20 AM
New secyrity alert by Firewall & order to take aktion on User Preferences
Security, Fieewall
Yestardey
FlyMore design mock-ups been uploadet by designers Bob, Naomi, Richard
PSD, Sketch, AJ
Aug 13,2018
Meeting with Ken Digital Corp ot Unit14, 3 Edigor Buildings, George Street, Loondon
England, BA12FJ
Meeting, Customer
May 09, 2018
KeenThemes created new layout whith tens of new options for Keen Admin panel
HTML,CSS,VueJS
01:20 AM
New secyrity alert by Firewall & order to take aktion on User Preferences
Security, Fieewall

### Recent Bills

Lorem Ipsum is simply dummy text of the printing and typesetting simply dummy text of the printing industry.
Dismiss View

### Latest Orders

Lorem Ipsum is simply dummy text of the printing and typesetting simply dummy text of the printing industry.
Dismiss View

### Latest Invoices

Lorem Ipsum is simply dummy text of the printing and typesetting simply dummy text of the printing industry.
Dismiss View

### New Comments

Lorem Ipsum is simply dummy text of the printing and typesetting simply dummy text of the printing industry.
Dismiss View

### Recent Posts

Lorem Ipsum is simply dummy text of the printing and typesetting simply dummy text of the printing industry.
Dismiss View
Notifications
Enable notifications:
Enable audit log:
Notify on new orders:
Orders
Enable order tracking:
Enable orders reports:
Allow order status auto update:
Customers
Enable customer singup:
Enable customers reporting:
Notifiy on new customer registration:

- Demos

### Select A Demo

Demo 1
Default RTL Version
Demo 2
Default RTL Version
Demo 3
Default RTL Version
Demo 4
Default RTL Version
Demo 5
Default RTL Version
Demo 6
Default RTL Version
Demo 7
Coming soon
Demo 8
Coming soon
Demo 9
Coming soon
Buy Keen Now!